@@ -209,6 +209,9 @@ INTERNALERROR_INTERNALSERVICEERRORERR = 'InternalError.InternalServiceErrorErr'
 # json解析失败。
 INTERNALERROR_JSONERROR = 'InternalError.JSONError'
 
+# 开通加密失败。
+INTERNALERROR_KMSERROR = 'InternalError.KmsError'
+
 # 网络错误。
 INTERNALERROR_NETWORKERROR = 'InternalError.NetworkError'
 
